@@ -515,12 +515,11 @@ class ProjectApps(Controller):
     def attach_certificate(self):
         project_id = self.app.pargs.project_id
         url = urllib3.util.parse_url(self.app.pargs.url)
-        url = (url.scheme or 'https') + '://' + url.host
         fqdn = self.app.pargs.fqdn
 
-        data = {'fqdn': fqdn, 'url': url}
+        data = {'fqdn': fqdn, 'url': url.host}
 
-        confirm = input('The certificate you specified will be attached to the project app. Are you sure? (Y/N)')
+        confirm = input(f'The certificate({fqdn}) will be attached to the project app. \nAre you sure? (Y/N) ')
 
         if confirm.capitalize() != 'Y':
             sys.exit(0)
